<?php

namespace Jlr\Tags\Api;

class Client extends \Jane\OpenApiRuntime\Client\Psr7HttplugClient
{
    /**
     * 
     *
     * @param array $queryParameters {
     *     @var string $filter[id] The id of the tag to retrieve
     *     @var string $filter[name] The name of the tag to retrieve
     *     @var bool $filter[user_generated] Get all tags that are user generated
     *     @var int $page[number] Get the tags from the current page
     *     @var int $page[size] Set the total number of tags to get in a single request
     *     @var string $include Comma separated list of all the relationships you want to include
     * }
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Jlr\Tags\Api\Model\TagsGetResponse200|\Psr\Http\Message\ResponseInterface
     */
    public function fetchTags(array $queryParameters = array(), string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\FetchTags($queryParameters), $fetch);
    }
    /**
     * 
     *
     * @param \Jlr\Tags\Api\Model\Tag $requestBody 
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Jlr\Tags\Api\Model\TagsPostResponse200|\Psr\Http\Message\ResponseInterface
     */
    public function createTag(\Jlr\Tags\Api\Model\Tag $requestBody, string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\CreateTag($requestBody), $fetch);
    }
    /**
     * 
     *
     * @param string $slug The slug of the tag to update.
     * @param \Jlr\Tags\Api\Model\Tag $requestBody 
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Jlr\Tags\Api\Model\TagsSlugPatchResponse200|\Psr\Http\Message\ResponseInterface
     */
    public function updateTag(string $slug, \Jlr\Tags\Api\Model\Tag $requestBody, string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\UpdateTag($slug, $requestBody), $fetch);
    }
    /**
     * 
     *
     * @param array $queryParameters {
     *     @var string $include Comma separated list of all the relationships you want to include
     * }
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Jlr\Tags\Api\Model\TagGroupsGetResponse200|\Psr\Http\Message\ResponseInterface
     */
    public function fetchTagGroups(array $queryParameters = array(), string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\FetchTagGroups($queryParameters), $fetch);
    }
    /**
     * 
     *
     * @param int $id The id of the tag-group to update.
     * @param \Jlr\Tags\Api\Model\TagGroup $requestBody 
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Jlr\Tags\Api\Model\TagGroupsIdPatchResponse200|\Psr\Http\Message\ResponseInterface
     */
    public function updateTagGroup(int $id, \Jlr\Tags\Api\Model\TagGroup $requestBody, string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\UpdateTagGroup($id, $requestBody), $fetch);
    }
    /**
     * 
     *
     * @param \Jlr\Tags\Api\Model\Onboarding $requestBody 
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Psr\Http\Message\ResponseInterface
     */
    public function updateOnboarding(\Jlr\Tags\Api\Model\Onboarding $requestBody, string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\UpdateOnboarding($requestBody), $fetch);
    }
    /**
     * 
     *
     * @param int $reportId The report being favourited/unfavourited for the user
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Psr\Http\Message\ResponseInterface
     */
    public function updateFavourite(int $reportId, string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\UpdateFavourite($reportId), $fetch);
    }
    /**
     * 
     *
     * @param array $queryParameters {
     *     @var string $filter[reports] The reports to download
     * }
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Psr\Http\Message\ResponseInterface
     */
    public function downloadReports(array $queryParameters = array(), string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\DownloadReports($queryParameters), $fetch);
    }
    /**
     * 
     *
     * @param array $queryParameters {
     *     @var string $filter[reports] The files to download
     * }
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Psr\Http\Message\ResponseInterface
     */
    public function downloadFiles(array $queryParameters = array(), string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\DownloadFiles($queryParameters), $fetch);
    }
    /**
     * 
     *
     * @param array $queryParameters {
     *     @var string $filter[id] The id of the report to retrieve
     *     @var string $filter[title] The title of the report to retrieve
     *     @var bool $filter[favourite] Only return reports that have been favourited
     *     @var string $sort[title] The field to sort by. Default sorting as ascending, adding the `-` will sort descending.
     *     @var int $page[number] Get the reports from the current page
     *     @var int $page[size] Set the total number of reports to get in a single request
     *     @var string $include Comma separated list of all the relationships you want to include
     * }
     * @param string $fetch Fetch mode to use (can be OBJECT or RESPONSE)
     *
     * @return null|\Jlr\Tags\Api\Model\ReportsGetResponse200|\Psr\Http\Message\ResponseInterface
     */
    public function fetchReports(array $queryParameters = array(), string $fetch = self::FETCH_OBJECT)
    {
        return $this->executePsr7Endpoint(new \Jlr\Tags\Api\Endpoint\FetchReports($queryParameters), $fetch);
    }
    public static function create($httpClient = null)
    {
        if (null === $httpClient) {
            $httpClient = \Http\Discovery\HttpClientDiscovery::find();
            $plugins = array();
            $uri = \Http\Discovery\UriFactoryDiscovery::find()->createUri('https://jlrcustomer.com/api');
            $plugins[] = new \Http\Client\Common\Plugin\AddHostPlugin($uri);
            $plugins[] = new \Http\Client\Common\Plugin\AddPathPlugin($uri);
            $httpClient = new \Http\Client\Common\PluginClient($httpClient, $plugins);
        }
        $messageFactory = \Http\Discovery\MessageFactoryDiscovery::find();
        $streamFactory = \Http\Discovery\StreamFactoryDiscovery::find();
        $serializer = new \Symfony\Component\Serializer\Serializer(\Jlr\Tags\Api\Normalizer\NormalizerFactory::create(), array(new \Symfony\Component\Serializer\Encoder\JsonEncoder(new \Symfony\Component\Serializer\Encoder\JsonEncode(), new \Symfony\Component\Serializer\Encoder\JsonDecode())));
        return new static($httpClient, $messageFactory, $serializer, $streamFactory);
    }
}