<?php

namespace Jlr\Tags;

use Http\Client\Common\Plugin\AddHostPlugin;
use Http\Client\Common\Plugin\AddPathPlugin;
use Http\Client\Common\Plugin\ErrorPlugin;
use Http\Client\Common\Plugin\HeaderDefaultsPlugin;
use Http\Client\Common\Plugin\QueryDefaultsPlugin;
use Http\Client\Common\PluginClient;
use Http\Discovery\HttpClientDiscovery;
use Http\Discovery\UriFactoryDiscovery;

class ClientFactory
{
    public static function make(string $uri, string $token): Client
    {
        $httpClient = HttpClientDiscovery::find();
        // Decorates the HTTP client with some plugins
        $uri = UriFactoryDiscovery::find()->createUri($uri);
        $pluginClient = new PluginClient($httpClient, [
            new ErrorPlugin(),
            new AddPathPlugin($uri),
            new AddHostPlugin($uri),
            new HeaderDefaultsPlugin([
                'Accept' => 'application/json',
            ]),
            new QueryDefaultsPlugin([
                'api_token' => $token,
            ]),
        ]);
        // Instantiate an OpenApi client generated by Jane
        return Client::create($pluginClient);
    }
}
